@@ -1,4 +1,4 @@
-# @(#)$Id: Bob.pm 351 2012-03-28 23:41:55Z pjf $
+# @(#)$Id: Bob.pm 355 2012-04-15 18:10:42Z pjf $
 
 package Bob;
 
@@ -9,32 +9,27 @@ use inc::CPANTesting;
 sub whimper { print {*STDOUT} $_[ 0 ]."\n"; exit 0 }
 
 BEGIN {
-   eval { require 5.010; }; $@ and whimper 'Perl minimum 5.10';
-   my $reason; $reason = CPANTesting::broken and whimper $reason;
+   my $reason; $reason = CPANTesting::broken_toolchain and whimper $reason;
 }
 
-use version; our $VERSION = qv( '1.1' );
+use version; our $VERSION = qv( '1.3' );
 
 use File::Spec::Functions;
 use Module::Build;
 
 sub new {
-   my ($class, $params) = @_; $params ||= {};
+   my ($class, $params) = @_; $params ||= {}; $params->{requires} ||= {};
 
-   my $module     = $params->{module} or whimper 'No module name';
-   my $distname   = $module; $distname =~ s{ :: }{-}gmx;
-   my $class_path = catfile( q(lib), split m{ :: }mx, $module.q(.pm) );
-   my $sub_class  = Module::Build->subclass( code => q{
-      sub ACTION_distmeta {
-         my $self = shift; use Pod::Select;
+   my $perl_ver   = $params->{requires}->{perl} || 5.008_008;
 
-         $self->notes->{create_readme_pod} and podselect( {
-            -output => q(README.pod) }, $self->dist_version_from );
+   $] < $perl_ver and whimper "Perl minimum ${perl_ver}";
 
-         return $self->SUPER::ACTION_distmeta;
-      } }, );
+   my $module      = $params->{module} or whimper 'No module name';
+   my $distname    = $module; $distname =~ s{ :: }{-}gmx;
+   my $class_path  = catfile( q(lib), split m{ :: }mx, $module.q(.pm) );
+   my $build_class = __get_build_class( $params );
 
-   return $sub_class->new
+   return $build_class->new
       ( add_to_cleanup     => [ q(Debian_CPANTS.txt), $distname.q(-*),
                                 map { ( q(*/) x $_ ).q(*~) } 0..5 ],
         build_requires     => $params->{build_requires},
@@ -58,6 +53,26 @@ sub new {
 sub __cpan_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
                      || ($ENV{PERL5OPT} || q()) =~ m{ CPAN-Reporter }mx) }
 
+sub __get_build_class {
+   # Which subclass of M::B should we create?
+   my $params = shift;
+
+   exists $params->{build_class} and return $params->{build_class};
+
+   return Module::Build->subclass( code => q{
+      use Pod::Select;
+
+      sub ACTION_distmeta {
+         my $self = shift;
+
+         $self->notes->{create_readme_pod} and podselect( {
+            -output => q(README.pod) }, $self->dist_version_from );
+
+         return $self->SUPER::ACTION_distmeta;
+      }
+   }, );
+}
+
 sub __get_no_index {
    my $params = shift;
 
@@ -65,11 +80,11 @@ sub __get_no_index {
 }
 
 sub __get_notes {
-   my $params = shift; my $notes = $params->{notes} || {};
+   my $params = shift;
+   my $notes  = exists $params->{notes} ? $params->{notes} : {};
 
    $notes->{create_readme_pod} = $params->{create_readme_pod} || 0;
-   $notes->{stop_tests} = ($params->{stop_tests} || 0) && __cpan_testing()
-                        ? 'CPAN Testing stopped' : 0;
+   $notes->{stop_tests       } = __stop_tests( $params );
 
    return $notes;
 }
@@ -104,6 +119,14 @@ sub __get_resources {
    return { resources => $resources };
 }
 
+sub __stop_tests {
+   my $params = shift; __cpan_testing() or return 0;
+
+   $params->{stop_tests} and return 'CPAN Testing stopped';
+
+   return CPANTesting::exceptions;
+}
+
 1;
 
 # Local Variables:
